==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/StyleShapeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StyleShapeEventArgsDescription } from "./StyleShapeEventArgsDescription";
/**
 * @hidden
 */
export let StyleShapeEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class StyleShapeEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (StyleShapeEventArgsDescriptionMetadata.a == null) {
                StyleShapeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                StyleShapeEventArgsDescriptionMetadata.c(StyleShapeEventArgsDescriptionMetadata.a);
            }
            if (a.k(StyleShapeEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ab(StyleShapeEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("ItemRef", "(w:Item,wf:Item)DataRef");
            a.item("ShapeFill", "(w:ShapeStyle.Fill,wf:ShapeFill)String");
            a.item("ShapeStroke", "(w:ShapeStyle.Stroke,wf:ShapeStroke)String");
            a.item("ShapeStrokeThickness", "(w:ShapeStyle.StrokeThickness,wf:ShapeStrokeThickness)Number:double");
            a.item("ShapeOpacity", "(w:ShapeStyle.Opacity,wf:ShapeOpacity)Number:double");
        }
        static d(a) {
            StyleShapeEventArgsDescriptionMetadata.b(a);
            a.ad("StyleShapeEventArgs", () => new StyleShapeEventArgsDescription());
            a.ac("StyleShapeEventArgs", StyleShapeEventArgsDescriptionMetadata.a);
        }
    }
    StyleShapeEventArgsDescriptionMetadata.$t = markType(StyleShapeEventArgsDescriptionMetadata, 'StyleShapeEventArgsDescriptionMetadata');
    StyleShapeEventArgsDescriptionMetadata.a = null;
    return StyleShapeEventArgsDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/StyleShapeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StyleShapeEventArgsDescription } from "./StyleShapeEventArgsDescription";
/**
 * @hidden
 */
export let StyleShapeEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class StyleShapeEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (StyleShapeEventArgsDescriptionMetadata.a == null) {
                StyleShapeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                StyleShapeEventArgsDescriptionMetadata.c(StyleShapeEventArgsDescriptionMetadata.a);
            }
            if (a.k(StyleShapeEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.ac(StyleShapeEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("ItemRef", "(w:Item,wf:Item)DataRef");
            a.item("ShapeFill", "(w:ShapeStyle.Fill,wf:ShapeFill)String");
            a.item("ShapeStroke", "(w:ShapeStyle.Stroke,wf:ShapeStroke)String");
            a.item("ShapeStrokeThickness", "(w:ShapeStyle.StrokeThickness,wf:ShapeStrokeThickness)Number:double");
            a.item("ShapeOpacity", "(w:ShapeStyle.Opacity,wf:ShapeOpacity)Number:double");
        }
        static d(a) {
            StyleShapeEventArgsDescriptionMetadata.b(a);
            a.ae("StyleShapeEventArgs", () => new StyleShapeEventArgsDescription());
            a.ad("StyleShapeEventArgs", StyleShapeEventArgsDescriptionMetadata.a);
        }
    }
    StyleShapeEventArgsDescriptionMetadata.$t = markType(StyleShapeEventArgsDescriptionMetadata, 'StyleShapeEventArgsDescriptionMetadata');
    StyleShapeEventArgsDescriptionMetadata.a = null;
    return StyleShapeEventArgsDescriptionMetadata;
})();
